@@ -65,6 +65,7 @@
 #include <CalendarSupport/CalPrinter>
 #include <CalendarSupport/IncidenceViewer>
 #include <CalendarSupport/KCalPrefs>
+#include <CalendarSupport/Utils>
 
 #include <IncidenceEditor/IncidenceDefaults>
 #include <IncidenceEditor/IncidenceDialog>
@@ -257,7 +258,9 @@ CalendarView::CalendarView(QWidget *parent)
             mDateNavigator, QOverload<const KCalendarCore::DateList &, const QDate &>::of(&DateNavigator::selectDates));
 
     connect(mViewManager, &KOViewManager::datesSelected,
-            mDateNavigator, [this](const KCalendarCore::DateList &dates) { mDateNavigator->selectDates(dates); });
+            mDateNavigator, [this](const KCalendarCore::DateList &dates) {
+        mDateNavigator->selectDates(dates);
+    });
 
     connect(mDateNavigatorContainer, &DateNavigatorContainer::incidenceDropped,
             this, &CalendarView::addIncidenceOn);
@@ -1010,8 +1013,7 @@ void CalendarView::newEvent(const QDateTime &startDtParam, const QDateTime &endD
     eventEditor->selectCollection(defaultCollection(KCalendarCore::Event::eventMimeType()));
 }
 
-void CalendarView::newEvent(const QString &summary, const QString &description, const QStringList &attachments, const QStringList &attendees, const QStringList &attachmentMimetypes,
-                            bool inlineAttachment)
+void CalendarView::newEvent(const QString &summary, const QString &description, const QStringList &attachments, const QStringList &attendees, const QStringList &attachmentMimetypes, bool inlineAttachment)
 {
     // Adjust the start/end date times (i.e. replace invalid values by defaults,
     // and let the view adjust the type.
@@ -1038,8 +1040,7 @@ void CalendarView::newEvent(const QString &summary, const QString &description,
     newEventEditor(event);
 }
 
-void CalendarView::newTodo(const QString &summary, const QString &description, const QStringList &attachments, const QStringList &attendees, const QStringList &attachmentMimetypes,
-                           bool inlineAttachment)
+void CalendarView::newTodo(const QString &summary, const QString &description, const QStringList &attachments, const QStringList &attendees, const QStringList &attachmentMimetypes, bool inlineAttachment)
 {
     Akonadi::Collection defaultCol = defaultCollection(KCalendarCore::Todo::todoMimeType());
 
@@ -1350,26 +1351,7 @@ void CalendarView::toggleAlarm(const Akonadi::Item &item)
     if (alarms.isEmpty()) {
         // Add an alarm if it didn't have one
         KCalendarCore::Alarm::Ptr alm = incidence->newAlarm();
-        alm->setType(KCalendarCore::Alarm::Display);
-        alm->setEnabled(true);
-        int duration; // in secs
-        switch (CalendarSupport::KCalPrefs::instance()->mReminderTimeUnits) {
-        default:
-        case 0: // mins
-            duration = CalendarSupport::KCalPrefs::instance()->mReminderTime * 60;
-            break;
-        case 1: // hours
-            duration = CalendarSupport::KCalPrefs::instance()->mReminderTime * 60 * 60;
-            break;
-        case 2: // days
-            duration = CalendarSupport::KCalPrefs::instance()->mReminderTime * 60 * 60 * 24;
-            break;
-        }
-        if (incidence->type() == KCalendarCore::Incidence::TypeEvent) {
-            alm->setStartOffset(KCalendarCore::Duration(-duration));
-        } else {
-            alm->setEndOffset(KCalendarCore::Duration(-duration));
-        }
+        CalendarSupport::createAlarmReminder(alm, incidence->type());
     }
     mChanger->startAtomicOperation(i18n("Toggle Reminder"));
     mChanger->modifyIncidence(item, oldincidence, this);
@@ -1624,7 +1606,7 @@ void CalendarView::dissociateOccurrence(const Akonadi::Item &item, const QDate &
     occurrenceDate.setDate(date);
     qCDebug(KORGANIZER_LOG) << "create exception: " << occurrenceDate;
     KCalendarCore::Incidence::Ptr newInc(KCalendarCore::Calendar::createException(
-                                        incidence, occurrenceDate, thisAndFuture));
+                                             incidence, occurrenceDate, thisAndFuture));
     if (newInc) {
         mChanger->createIncidence(newInc, item.parentCollection(), this);
     } else {
@@ -1993,7 +1975,7 @@ void CalendarView::takeOverEvent()
     }
 
     incidence->setOrganizer(KCalendarCore::Person(CalendarSupport::KCalPrefs::instance()->fullName(),
-                                             CalendarSupport::KCalPrefs::instance()->email()));
+                                                  CalendarSupport::KCalPrefs::instance()->email()));
     incidence->recreate();
     incidence->setReadOnly(false);
 
