@@ -43,7 +43,7 @@ public:
 protected:
     void loadUiFiles();
     void loadActivePages(const QStringList &);
-    QStringList saveActivePages();
+    Q_REQUIRED_RESULT QStringList saveActivePages();
 
     virtual QString localUiDir() = 0;
     virtual QString uiPath() = 0;
